:- module(html_generation_types,
	[
	    pred_html_spec/1,
	    pred_html_spec_list/1,
	    html_spec/1,
	    field_basic_val/1,
	    display_mode/1
	],
	[assertions, regtypes]).


:- true prop pred_html_spec(S) + regtype # "@var(S) is the
	specification of the HTML representation of a predicate.".

pred_html_spec(S) :-
	S =..[_|HTMLTypes],
	pred_html_spec_list(HTMLTypes).

:- true prop pred_html_spec_list(S) + regtype # "@var(S) is a list
	containing the specification of the HTML representation of the
	arguments of a predicate.".

pred_html_spec_list(S) :-
	list(S, html_spec).

:- true prop html_spec(S) + regtype # "@var(S) is the specification of
	the HTML representation of a predicate argument. It is at the
	same time a way to represent data and allow the user to edit
	it by providing an HTML form input element. Currently, there
	is a set of basic ones. More can be added by adding new
	entries to the html_format file".

html_spec(name(Description, DefaultValue, Length)) :- 
	common_spec(Description, DefaultValue, Length).	
html_spec(textinput(Description, DefaultValue, Rows, Cols)) :-
	common_spec(Description, DefaultValue, Rows),
	int(Cols).	
html_spec(number(Description, DefaultValue, Length)) :- 
	atm(Description), 
	int(DefaultValue), 
	int(Length).
html_spec(passwd(Description, DefaultValue, Length)) :- 
	common_spec(Description, DefaultValue, Length).	
html_spec(checkbox(Description, DefaultState)) :-
	atm(Description), 
	atm(DefaultState).
html_spec(menu(Description, Size, Atts, Options)) :-
	atm(Description), 
	int(Size),
	list(Atts, term),
	list(Options, atm).
html_spec(input_img(Description, DefaultImg, Length)) :-
	common_spec(Description, DefaultImg, Length).	
html_spec(input_link(Description, DefaultLink, Length)) :-
	common_spec(Description, DefaultLink, Length).	
html_spec(color(Description, DefaultValue)) :-
	atm(Description), 
	atm(DefaultValue).

common_spec(Description, DefaultValue, Length) :-
	atm(Description), 
	atm(DefaultValue), 
	int(Length).

:- true prop field_basic_val(Val) + regtype # "@var(Val) is the value of a form field.".

field_basic_val(Val) :-
	atm(Val).
field_basic_val(Val) :-
	int(Val).

:- true prop display_mode(M) + regtype # "@var(V) is the visibility
	chosen for a particular data during user interaction with an
	HTML interface. It can be public or private, depending on
	whether the data is to be shown to an admin or to a common
	user ".

display_mode(public).
display_mode(private).
